==> haskell-cabal-install-parsers-0.6-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install-parsers
version:              0.6
visibility:           public
id:                   cabal-install-parsers-0.6-KbJq3KEOYZV7uXGweGDI8d
key:                  cabal-install-parsers-0.6-KbJq3KEOYZV7uXGweGDI8d
license:              GPL-2.0-or-later AND BSD-3-Clause
maintainer:           hvr@gnu.org, oleg.grenrus@iki.fi
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Utilities to work with cabal-install files
description:
    @cabal-install-parsers@ provides parsers for @cabal-install@ files:
    @cabal.project@ ("Cabal.Project"),
    @cabal.config@ ("Cabal.Config"),
    @01-index.tar@ ("Cabal.Index");
    as well as some other utilities.

    The feature set is mainly motivated by the needs of @haskell-ci@ package.
    The parsed data is not complete, functionality is added on demand.

category:             Development
abi:                  a693a9e2276c35c089b61c412689a753
exposed:              True
exposed-modules:
    Cabal.Config Cabal.Index Cabal.Optimization Cabal.Package
    Cabal.Parse Cabal.Project Cabal.SourceRepo

hidden-modules:       Cabal.Internal.Glob Cabal.Internal.Newtypes
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-install-parsers-0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-install-parsers-0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-install-parsers-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-parsers
hs-libraries:         HScabal-install-parsers-0.6-KbJq3KEOYZV7uXGweGDI8d
depends:
    Cabal-syntax-3.8.1.0 aeson-2.1.2.1-Gng3eoGBP2Sj2fbUBsnWH
    base-4.17.2.1 base16-bytestring-1.0.2.0-8y3SyptL8obHk6RuDrxcpW
    binary-0.8.9.1 binary-instances-1.0.4-DeB9nRJEWNMBGPAcpYUHgi
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-B0dHxYRWPrO346e6jKDe9T deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2
    lukko-0.1.1.3-BMWZuMqG4jf4MtKP4YqACe
    network-uri-2.6.4.2-3JlqJJTWpo6F8MNpnCbeng parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-LXDZvC1IcjWJA4zfib2Nqi text-2.0.2
    time-1.12.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-parsers/html/cabal-install-parsers.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-install-parsers-0.6-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install-parsers
version:              0.6
visibility:           public
id:                   cabal-install-parsers-0.6-HE6EIPSsiOk2j9co9m5jE4
key:                  cabal-install-parsers-0.6-HE6EIPSsiOk2j9co9m5jE4
license:              GPL-2.0-or-later AND BSD-3-Clause
maintainer:           hvr@gnu.org, oleg.grenrus@iki.fi
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Utilities to work with cabal-install files
description:
    @cabal-install-parsers@ provides parsers for @cabal-install@ files:
    @cabal.project@ ("Cabal.Project"),
    @cabal.config@ ("Cabal.Config"),
    @01-index.tar@ ("Cabal.Index");
    as well as some other utilities.

    The feature set is mainly motivated by the needs of @haskell-ci@ package.
    The parsed data is not complete, functionality is added on demand.

category:             Development
abi:                  6ab8c37ccd5118a51a98028bc0681990
exposed:              True
exposed-modules:
    Cabal.Config Cabal.Index Cabal.Optimization Cabal.Package
    Cabal.Parse Cabal.Project Cabal.SourceRepo

hidden-modules:       Cabal.Internal.Glob Cabal.Internal.Newtypes
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-install-parsers-0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-install-parsers-0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-install-parsers-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-parsers
hs-libraries:         HScabal-install-parsers-0.6-HE6EIPSsiOk2j9co9m5jE4
depends:
    Cabal-syntax-3.8.1.0 aeson-2.1.2.1-Gng3eoGBP2Sj2fbUBsnWH
    base-4.17.2.1 base16-bytestring-1.0.2.0-8y3SyptL8obHk6RuDrxcpW
    binary-0.8.9.1 binary-instances-1.0.4-DeB9nRJEWNMBGPAcpYUHgi
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-B0dHxYRWPrO346e6jKDe9T deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2
    lukko-0.1.1.3-BMWZuMqG4jf4MtKP4YqACe
    network-uri-2.6.4.2-3JlqJJTWpo6F8MNpnCbeng parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-LXDZvC1IcjWJA4zfib2Nqi text-2.0.2
    time-1.12.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-parsers/html/cabal-install-parsers.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
